-------------------------------------------------------------------------------
-- Localized Lua globals
-------------------------------------------------------------------------------
local _G = getfenv(0)

local string = _G.string
local math = _G.math

-------------------------------------------------------------------------------
-- AddOn namespace
-------------------------------------------------------------------------------
local ADDON_NAME, private = ...
local GearGauge = LibStub("AceAddon-3.0"):GetAddon(ADDON_NAME)

local dev = false
--[===[@debug@
dev = true
--@end-debug@]===]
local L = LibStub("AceLocale-3.0"):GetLocale(ADDON_NAME, "enUS", true, dev)

local version = GetAddOnMetadata(ADDON_NAME, "Version")
version = string.gsub(version, "@project.version@", " - Development")

-------------------------------------------------------------------------------
-- Constants
-------------------------------------------------------------------------------
local MAX_PLAYER_LEVEL = 80	-- Override the global one, since people without WoTLK will have it set to 70 (or 60 without TBC). Sad, I know.

-------------------------------------------------------------------------------
-- Configuration
-------------------------------------------------------------------------------
local TOOLTIP_COLORING_VALUES = {
	["Line"]	= L["Line"],
	["Text"]	= L["Text"],
	["Both"]	= L["Line and Text"],
}
local options

local function GetOptions()
	if options then return options end

	local db = GearGauge.db

	options = {
		type	= "group",
		name	= ADDON_NAME,
		args = {
			about = {
				order	= 1,
				type	= "description",
				name	= GAME_VERSION_LABEL.." "..version,
			},
			spacer_1 = {
				order		= 2,
				type		= "description",
				name		= " ",
				cmdHidden	= true
			},
			minimap_icon = {
				order	= 2,
				type	= "toggle",
				name	= L["MINIMAP_ICON_NAME"],
				desc	= L["MINIMAP_ICON_DESC"],
				get	= function() return not db.global.minimap_icon.hide end,
				set	= function(info, val)
						  db.global.minimap_icon.hide = not val

						  if val then
							  LibStub("LibDBIcon-1.0"):Show(ADDON_NAME)
						  else
							  LibStub("LibDBIcon-1.0"):Hide(ADDON_NAME)
						  end
					  end,
			},
			-------------------------------------------------------------------------------
			-- Scanning options.
			-------------------------------------------------------------------------------
			scanning = {
				order	= 4,
				type	= "group",
				name	= L["Scanning"],
				desc	= L["SCANNING_OPTIONS_DESC"],
				args = {
					scanning_desc = {
						order	= 1,
						type	= "description",
						name	= L["SCANNING_OPTIONS_DESC"].."\n",
					},
					minlev = {
						order	= 2,
						type	= "range",
						name	= L["Minimum Level"],
						desc	= L["SCAN_MINLEVEL_DESC"],
						min	= 1,
						max	= MAX_PLAYER_LEVEL,
						step	= 1,
						get	= function() return db.global.scanning.minlevel end,
						set	= function(info, val)
								  db.global.scanning.minlevel = math.max(1, math.min(db.global.scanning.maxlevel, val))
							  end,
					},
					maxlev = {
						order	= 3,
						type	= "range",
						name	= L["Maximum Level"],
						desc	= L["SCAN_MAXLEVEL_DESC"],
						min	= 1,
						max	= MAX_PLAYER_LEVEL,
						step	= 1,
						get	= function() return db.global.scanning.maxlevel end,
						set	= function(info, val)
								  db.global.scanning.maxlevel = math.min(MAX_PLAYER_LEVEL, math.max(db.global.scanning.minlevel, val))
							  end,
					},
					delay = {
						order	= 4,
						type	= "range",
						name	= L["Delay"],
						desc	= L["SCAN_DELAY_DESC"],
						min	= 1,
						max	= 60,
						step	= 1,
						get	= function() return db.global.scanning.delay end,
						set	= function(info, val) db.global.scanning.delay = math.min(60, math.max(1, val)) end,
					},
					persistence = {
						order	= 5,
						type	= "range",
						name	= L["Persistence"],
						desc	= L["SCAN_PERSISTENCE_DESC"],
						min	= 1,
						max	= 30,
						step	= 1,
						get	= function() return db.global.scanning.persistence end,
						set	= function(info, val) db.global.scanning.persistence = math.min(30, math.max(1, val)) end,
					},
					spacer_1 = {
						order		= 6,
						type		= "description",
						name		= " ",
						cmdHidden	= true
					},
					notify = {
						order	= 7,
						type	= "toggle",
						name	= L["Notify"],
						desc	= L["SCAN_NOTIFY_DESC"],
						get	= function() return db.global.scanning.notify end,
						set	= function() db.global.scanning.notify = not db.global.scanning.notify end,
					},
					enemies = {
						order	= 8,
						type	= "toggle",
						name	= L["Scan Enemies"],
						desc	= L["SCAN_ENEMIES_DESC"],
						get	= function() return db.global.scanning.enemies end,
						set	= function() db.global.scanning.enemies = not db.global.scanning.enemies end,
					},
				},
			},
			-------------------------------------------------------------------------------
			-- Tooltip options.
			-------------------------------------------------------------------------------
			tooltip = {
				order	= 5,
				type	= "group",
				name	= L["Tooltip"],
				desc	= L["TOOLTIP_OPTIONS_DESC"],
				args = {
					tooltip_desc = {
						order	= 1,
						type	= "description",
						name	= L["TOOLTIP_OPTIONS_DESC"].."\n",
					},
					scale = {
						order	= 1,
						type	= "range",
						name	= L["Scale"],
						desc	= L["TOOLTIP_SCALE_DESC"],
						min	= 0.5,
						max	= 2.0,
						step	= 0.05,
						get	= function() return db.global.tooltip.scale end,
						set	= function(info, val) db.global.tooltip.scale = math.min(2.0, math.max(0.5, val)) end,
					},
					timer = {
						order	= 2,
						type	= "range",
						name	= L["Timer"],
						desc	= L["TOOLTIP_TIMER_DESC"],
						min	= 0.25,
						max	= 3.0,
						step	= 0.05,
						get	= function() return db.global.tooltip.timer end,
						set	= function(info, val) db.global.tooltip.timer = math.min(3.0, math.max(0.25, val)) end,
					},
					coloring = {
						order	= 3,
						type	= "select",
						name	= L["Coloring"],
						desc	= L["TOOLTIP_COLORING_DESC"],
						get	= function() return db.global.tooltip.coloring end,
						set	= function(info, val) db.global.tooltip.coloring = val end,
						values	= TOOLTIP_COLORING_VALUES,
					},
				},
			},
		},
	}
	return options
end

function GearGauge:SetupOptions()
	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable(ADDON_NAME, GetOptions())
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions(ADDON_NAME)
end
